summaryrefslogtreecommitdiffstats
path: root/kmail/kmfolderdia.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-04-13 00:46:47 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-04-13 00:46:47 +0000
commit67e29a054cfcb1b0d2fe6b0a316cf6b3eec087b7 (patch)
tree5f52a9eada2e9f3654fc327d7c14dfef570a6ecb /kmail/kmfolderdia.cpp
parent2ee4bf4fd5eff93b2fbef0ff8e8063edffc5da5c (diff)
downloadtdepim-67e29a054cfcb1b0d2fe6b0a316cf6b3eec087b7.tar.gz
tdepim-67e29a054cfcb1b0d2fe6b0a316cf6b3eec087b7.zip
Initial conversion of kdepim to TQt
This will probably require some tweaking before it will build under Qt4, however Qt3 builds are OK. Any alterations this commit makes to kdepim behaviour under Qt3 are unintentional and should be fixed. git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdepim@1227832 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kmail/kmfolderdia.cpp')
-rw-r--r--kmail/kmfolderdia.cpp60
1 files changed, 30 insertions, 30 deletions
diff --git a/kmail/kmfolderdia.cpp b/kmail/kmfolderdia.cpp
index 4e17ce23..9d514614 100644
--- a/kmail/kmfolderdia.cpp
+++ b/kmail/kmfolderdia.cpp
@@ -20,11 +20,11 @@
*
* In addition, as a special exception, the copyright holders give
* permission to link the code of this program with any edition of
- * the Qt library by Trolltech AS, Norway (or with modified versions
- * of Qt that use the same license as Qt), and distribute linked
+ * the TQt library by Trolltech AS, Norway (or with modified versions
+ * of TQt that use the same license as TQt), and distribute linked
* combinations including the two. You must obey the GNU General
* Public License in all respects for all of the code used other than
- * Qt. If you modify this file, you may extend this exception to
+ * TQt. If you modify this file, you may extend this exception to
* your version of the file, but you are not obligated to do so. If
* you do not wish to do so, delete this exception statement from
* your version.
@@ -100,12 +100,12 @@ KMFolderDialog::KMFolderDialog(KMFolder *aFolder, KMFolderDir *aFolderDir,
TQStringList folderNames;
TQValueList<TQGuardedPtr<KMFolder> > folders;
- // get all folders but search and folders that can not have children
+ // get all folders but search and folders that can not have tqchildren
aParent->createFolderList(&folderNames, &folders, true, true,
true, false, true, false);
if( mFolderDir ) {
// search the parent folder of the folder
FolderList::ConstIterator it;
int i = 1;
for( it = folders.begin(); it != folders.end(); ++it, ++i ) {
@@ -185,7 +185,7 @@ void KMFolderDialog::slotOk()
mDelayedSavingTabs = 0; // number of tabs which need delayed saving
for ( unsigned int i = 0 ; i < mTabs.count() ; ++i ) {
- FolderDiaTab::AccepStatus s = mTabs[i]->accept();
+ FolderDiaTab::AcceptqStatus s = mTabs[i]->accept();
if ( s == FolderDiaTab::Canceled ) {
slotCancelAccept();
return;
@@ -234,9 +234,9 @@ void KMFolderDialog::setFolder( KMFolder* folder )
mFolder = folder;
}
-static void addLine( TQWidget *parent, TQVBoxLayout* tqlayout )
+static void addLine( TQWidget *tqparent, TQVBoxLayout* tqlayout )
{
- TQFrame *line = new TQFrame( parent, "line" );
+ TQFrame *line = new TQFrame( tqparent, "line" );
line->setGeometry( TQRect( 80, 150, 250, 20 ) );
line->setFrameShape( TQFrame::HLine );
line->setFrameShadow( TQFrame::Sunken );
@@ -247,8 +247,8 @@ static void addLine( TQWidget *parent, TQVBoxLayout* tqlayout )
//----------------------------------------------------------------------------
KMail::FolderDiaGeneralTab::FolderDiaGeneralTab( KMFolderDialog* dlg,
const TQString& aName,
- TQWidget* parent, const char* name )
- : FolderDiaTab( parent, name ),
+ TQWidget* tqparent, const char* name )
+ : FolderDiaTab( tqparent, name ),
mSharedSeenFlagsCheckBox( 0 ),
mDlg( dlg )
{
@@ -272,8 +272,8 @@ KMail::FolderDiaGeneralTab::FolderDiaGeneralTab( KMFolderDialog* dlg,
// Determine if we are allowed to rename this folder. Only possible if the folder supports
// ACLs.
bool nameChangeAllowed = true;
- if ( mDlg->folder() && mDlg->parentFolder() &&
- mDlg->folder()->storage() && mDlg->parentFolder()->storage() &&
+ if ( mDlg->folder() && mDlg->tqparentFolder() &&
+ mDlg->folder()->storage() && mDlg->tqparentFolder()->storage() &&
( mDlg->folder()->folderType() == KMFolderTypeCachedImap ||
mDlg->folder()->folderType() == KMFolderTypeImap ) ) {
ImapAccountBase *account = 0;
@@ -289,31 +289,31 @@ KMail::FolderDiaGeneralTab::FolderDiaGeneralTab( KMFolderDialog* dlg,
}
if ( account && account->hasACLSupport() ) {
- int parentRights = -1;
+ int tqparentRights = -1;
int folderRights = -1;
- bool parentRightsOk = false;
+ bool tqparentRightsOk = false;
bool folderRightsOk = false;
if ( imap ) {
- KMFolderImap * const parent = dynamic_cast<KMFolderImap*>( mDlg->parentFolder()->storage() );
+ KMFolderImap * const tqparent = dynamic_cast<KMFolderImap*>( mDlg->tqparentFolder()->storage() );
folderRights = imap->userRights();
folderRightsOk = imap->userRightsState() == KMail::ACLJobs::Ok;
- if ( parent ) {
- parentRights = parent->userRights();
- parentRightsOk = parent->userRightsState() == KMail::ACLJobs::Ok;
+ if ( tqparent ) {
+ tqparentRights = tqparent->userRights();
+ tqparentRightsOk = tqparent->userRightsState() == KMail::ACLJobs::Ok;
}
} else if ( dimap ) {
- KMFolderCachedImap * const parent = dynamic_cast<KMFolderCachedImap*>( mDlg->parentFolder()->storage() );
+ KMFolderCachedImap * const tqparent = dynamic_cast<KMFolderCachedImap*>( mDlg->tqparentFolder()->storage() );
folderRights = dimap->userRights();
folderRightsOk = dimap->userRightsState() == KMail::ACLJobs::Ok;
- if ( parent ) {
- parentRights = parent->userRights();
- parentRightsOk = parent->userRightsState() == KMail::ACLJobs::Ok;
+ if ( tqparent ) {
+ tqparentRights = tqparent->userRights();
+ tqparentRightsOk = tqparent->userRightsState() == KMail::ACLJobs::Ok;
}
}
// For renaming, we need support for deleting the mailbox and then re-creating it.
- if ( parentRightsOk && folderRightsOk &&
- ( !( parentRights & KMail::ACLJobs::Create ) || !( folderRights & KMail::ACLJobs::Delete ) ) ) {
+ if ( tqparentRightsOk && folderRightsOk &&
+ ( !( tqparentRights & KMail::ACLJobs::Create ) || !( folderRights & KMail::ACLJobs::Delete ) ) ) {
nameChangeAllowed = false;
}
}
@@ -325,7 +325,7 @@ KMail::FolderDiaGeneralTab::FolderDiaGeneralTab( KMFolderDialog* dlg,
mNameEdit->setEnabled( nameChangeAllowed );
if ( !nameChangeAllowed ) {
TQToolTip::add( mNameEdit, i18n( "Not enough permissions to rename this folder.\n"
- "The parent folder doesn't have write support.\n"
+ "The tqparent folder doesn't have write support.\n"
"A sync is needed after changing the permissions." ) );
}
mNameEdit->setText( mDlg->folder() ? mDlg->folder()->label() : i18n("unnamed") );
@@ -702,9 +702,9 @@ bool FolderDiaGeneralTab::save()
else
fldName = oldFldName;
- if ( mDlg->parentFolder() &&
- mDlg->parentFolder()->folderType() != KMFolderTypeImap &&
- mDlg->parentFolder()->folderType() != KMFolderTypeCachedImap )
+ if ( mDlg->tqparentFolder() &&
+ mDlg->tqparentFolder()->folderType() != KMFolderTypeImap &&
+ mDlg->tqparentFolder()->folderType() != KMFolderTypeCachedImap )
fldName.remove('/');
fldName.remove(TQRegExp("^\\.*"));
if (fldName.isEmpty()) fldName = i18n("unnamed");
@@ -796,8 +796,8 @@ void FolderDiaGeneralTab::slotChangeIcon( TQString icon ) // can't use a const-r
//----------------------------------------------------------------------------
KMail::FolderDiaTemplatesTab::FolderDiaTemplatesTab( KMFolderDialog* dlg,
- TQWidget* parent )
- : FolderDiaTab( parent, 0 ), mDlg( dlg )
+ TQWidget* tqparent )
+ : FolderDiaTab( tqparent, 0 ), mDlg( dlg )
{
mIsLocalSystemFolder = mDlg->folder()->isSystemFolder();
@@ -100,12 +100,12 @@ KMFolderDialog::KMFolderDialog(KMFolder *aFolder, KMFolderDir *aFolderDir,
true, false, true, false);
if( mFolderDir ) {
- // search the parent folder of the folder
+ // search the tqparent folder of the folder
FolderList::ConstIterator it;
int i = 1;